# coding: utf-8

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic.v1 import BaseModel, Field, constr, validator

class MatchingPattern(BaseModel):
    """
    A matching pattern object  # noqa: E501
    """
    event_type: constr(strict=True, max_length=512, min_length=0) = Field(..., alias="eventType", description="The type of event to subscribe to. The list of available event types can be discovered  by calling the ‘List available EventTypes’ API endpoint.")
    filter: Optional[constr(strict=True, max_length=16384, min_length=0)] = Field(None, description="A filter on the event. See https://support.lusid.com/filtering-results-from-lusid for more information. If not provided, all events will be matched")
    __properties = ["eventType", "filter"]

    @validator('event_type')
    def event_type_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-zA-Z]*$", value):
            raise ValueError(r"must validate the regular expression /^[a-zA-Z]*$/")
        return value

    @validator('filter')
    def filter_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[\s\S]*$", value):
            raise ValueError(r"must validate the regular expression /^[\s\S]*$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MatchingPattern:
        """Create an instance of MatchingPattern from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if filter (nullable) is None
        # and __fields_set__ contains the field
        if self.filter is None and "filter" in self.__fields_set__:
            _dict['filter'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MatchingPattern:
        """Create an instance of MatchingPattern from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MatchingPattern.parse_obj(obj)

        _obj = MatchingPattern.parse_obj({
            "event_type": obj.get("eventType"),
            "filter": obj.get("filter")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic.v1 import BaseModel, Field, StrictStr

class AmazonSqsNotificationTypeResponse(BaseModel):
    """
    Holds readonly information about an AWS SQS notification  # noqa: E501
    """
    type: Optional[StrictStr] = Field(None, description="The type of delivery mechanism for this notification")
    api_key_ref: Optional[StrictStr] = Field(None, alias="apiKeyRef", description="Reference to API key from Configuration Store")
    api_secret_ref: Optional[StrictStr] = Field(None, alias="apiSecretRef", description="Reference to API secret from Configuration Store")
    body: Optional[StrictStr] = Field(None, description="The body of the Amazon Queue Message")
    queue_url_ref: Optional[StrictStr] = Field(None, alias="queueUrlRef", description="Reference to queue url from Configuration Store")
    __properties = ["type", "apiKeyRef", "apiSecretRef", "body", "queueUrlRef"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AmazonSqsNotificationTypeResponse:
        """Create an instance of AmazonSqsNotificationTypeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if type (nullable) is None
        # and __fields_set__ contains the field
        if self.type is None and "type" in self.__fields_set__:
            _dict['type'] = None

        # set to None if api_key_ref (nullable) is None
        # and __fields_set__ contains the field
        if self.api_key_ref is None and "api_key_ref" in self.__fields_set__:
            _dict['apiKeyRef'] = None

        # set to None if api_secret_ref (nullable) is None
        # and __fields_set__ contains the field
        if self.api_secret_ref is None and "api_secret_ref" in self.__fields_set__:
            _dict['apiSecretRef'] = None

        # set to None if body (nullable) is None
        # and __fields_set__ contains the field
        if self.body is None and "body" in self.__fields_set__:
            _dict['body'] = None

        # set to None if queue_url_ref (nullable) is None
        # and __fields_set__ contains the field
        if self.queue_url_ref is None and "queue_url_ref" in self.__fields_set__:
            _dict['queueUrlRef'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AmazonSqsNotificationTypeResponse:
        """Create an instance of AmazonSqsNotificationTypeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AmazonSqsNotificationTypeResponse.parse_obj(obj)

        _obj = AmazonSqsNotificationTypeResponse.parse_obj({
            "type": obj.get("type"),
            "api_key_ref": obj.get("apiKeyRef"),
            "api_secret_ref": obj.get("apiSecretRef"),
            "body": obj.get("body"),
            "queue_url_ref": obj.get("queueUrlRef")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic.v1 import BaseModel, Field, constr, validator
from lusid_notifications.models.matching_pattern import MatchingPattern
from lusid_notifications.models.resource_id import ResourceId

class CreateSubscription(BaseModel):
    """
    The information required to create a subscription  # noqa: E501
    """
    id: ResourceId = Field(...)
    display_name: constr(strict=True, max_length=64, min_length=1) = Field(..., alias="displayName", description="The name of the subscription")
    description: Optional[constr(strict=True, max_length=512, min_length=1)] = Field(None, description="The summary of the services provided by the subscription")
    status: constr(strict=True, min_length=1) = Field(..., description="The current status of the subscription. Possible values are: Active, Inactive")
    matching_pattern: MatchingPattern = Field(..., alias="matchingPattern")
    use_as_auth: Optional[constr(strict=True, max_length=64, min_length=1)] = Field(None, alias="useAsAuth", description="Id of user associated with subscription. All events associated with   the subscription will use this user to check entitlements against   the resource to send a notification. Can be null, in which case   we'll default to that of the user making this request")
    __properties = ["id", "displayName", "description", "status", "matchingPattern", "useAsAuth"]

    @validator('display_name')
    def display_name_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[\s\S]*$", value):
            raise ValueError(r"must validate the regular expression /^[\s\S]*$/")
        return value

    @validator('description')
    def description_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[\s\S]*$", value):
            raise ValueError(r"must validate the regular expression /^[\s\S]*$/")
        return value

    @validator('use_as_auth')
    def use_as_auth_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[a-zA-Z0-9\-_]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-zA-Z0-9\-_]+$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateSubscription:
        """Create an instance of CreateSubscription from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of id
        if self.id:
            _dict['id'] = self.id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of matching_pattern
        if self.matching_pattern:
            _dict['matchingPattern'] = self.matching_pattern.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict['description'] = None

        # set to None if use_as_auth (nullable) is None
        # and __fields_set__ contains the field
        if self.use_as_auth is None and "use_as_auth" in self.__fields_set__:
            _dict['useAsAuth'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateSubscription:
        """Create an instance of CreateSubscription from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateSubscription.parse_obj(obj)

        _obj = CreateSubscription.parse_obj({
            "id": ResourceId.from_dict(obj.get("id")) if obj.get("id") is not None else None,
            "display_name": obj.get("displayName"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "matching_pattern": MatchingPattern.from_dict(obj.get("matchingPattern")) if obj.get("matchingPattern") is not None else None,
            "use_as_auth": obj.get("useAsAuth")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict
from pydantic.v1 import BaseModel, Field, StrictInt
from lusid_notifications.models.attempt_status import AttemptStatus

class Attempt(BaseModel):
    """
    Details of an attempt of delivery.  # noqa: E501
    """
    attempt_number: StrictInt = Field(..., alias="attemptNumber", description="The attempt number of the delivery.")
    attempt_time: datetime = Field(..., alias="attemptTime", description="The time that the delivery was attempted.")
    status: AttemptStatus = Field(...)
    __properties = ["attemptNumber", "attemptTime", "status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Attempt:
        """Create an instance of Attempt from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Attempt:
        """Create an instance of Attempt from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Attempt.parse_obj(obj)

        _obj = Attempt.parse_obj({
            "attempt_number": obj.get("attemptNumber"),
            "attempt_time": obj.get("attemptTime"),
            "status": AttemptStatus.from_dict(obj.get("status")) if obj.get("status") is not None else None
        })
        return _obj



# coding: utf-8

# flake8: noqa

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import absolute_import

# import apis into sdk package
from lusid_notifications.api.application_metadata_api import ApplicationMetadataApi
from lusid_notifications.api.deliveries_api import DeliveriesApi
from lusid_notifications.api.event_types_api import EventTypesApi
from lusid_notifications.api.manual_event_api import ManualEventApi
from lusid_notifications.api.notifications_api import NotificationsApi
from lusid_notifications.api.subscriptions_api import SubscriptionsApi

# import ApiClient
from lusid_notifications.api_client import ApiClient
from lusid_notifications.configuration import Configuration
from lusid_notifications.exceptions import OpenApiException
from lusid_notifications.exceptions import ApiTypeError
from lusid_notifications.exceptions import ApiValueError
from lusid_notifications.exceptions import ApiKeyError
from lusid_notifications.exceptions import ApiException
# import models into sdk package
from lusid_notifications.models.access_controlled_action import AccessControlledAction
from lusid_notifications.models.access_controlled_resource import AccessControlledResource
from lusid_notifications.models.action_id import ActionId
from lusid_notifications.models.amazon_sqs_notification_type import AmazonSqsNotificationType
from lusid_notifications.models.amazon_sqs_notification_type_response import AmazonSqsNotificationTypeResponse
from lusid_notifications.models.amazon_sqs_principal_auth_notification_type import AmazonSqsPrincipalAuthNotificationType
from lusid_notifications.models.amazon_sqs_principal_auth_notification_type_response import AmazonSqsPrincipalAuthNotificationTypeResponse
from lusid_notifications.models.attempt import Attempt
from lusid_notifications.models.attempt_status import AttemptStatus
from lusid_notifications.models.create_notification_request import CreateNotificationRequest
from lusid_notifications.models.create_subscription import CreateSubscription
from lusid_notifications.models.delivery import Delivery
from lusid_notifications.models.email_notification_type import EmailNotificationType
from lusid_notifications.models.email_notification_type_response import EmailNotificationTypeResponse
from lusid_notifications.models.event_field_definition import EventFieldDefinition
from lusid_notifications.models.event_type_schema import EventTypeSchema
from lusid_notifications.models.id_selector_definition import IdSelectorDefinition
from lusid_notifications.models.identifier_part_schema import IdentifierPartSchema
from lusid_notifications.models.link import Link
from lusid_notifications.models.lusid_problem_details import LusidProblemDetails
from lusid_notifications.models.lusid_validation_problem_details import LusidValidationProblemDetails
from lusid_notifications.models.manual_event import ManualEvent
from lusid_notifications.models.manual_event_body import ManualEventBody
from lusid_notifications.models.manual_event_header import ManualEventHeader
from lusid_notifications.models.manual_event_request import ManualEventRequest
from lusid_notifications.models.matching_pattern import MatchingPattern
from lusid_notifications.models.notification import Notification
from lusid_notifications.models.notification_status import NotificationStatus
from lusid_notifications.models.notification_type import NotificationType
from lusid_notifications.models.notification_type_response import NotificationTypeResponse
from lusid_notifications.models.resource_id import ResourceId
from lusid_notifications.models.resource_list_of_access_controlled_resource import ResourceListOfAccessControlledResource
from lusid_notifications.models.resource_list_of_delivery import ResourceListOfDelivery
from lusid_notifications.models.resource_list_of_event_type_schema import ResourceListOfEventTypeSchema
from lusid_notifications.models.resource_list_of_notification import ResourceListOfNotification
from lusid_notifications.models.resource_list_of_subscription import ResourceListOfSubscription
from lusid_notifications.models.sms_notification_type import SmsNotificationType
from lusid_notifications.models.sms_notification_type_response import SmsNotificationTypeResponse
from lusid_notifications.models.subscription import Subscription
from lusid_notifications.models.update_notification_request import UpdateNotificationRequest
from lusid_notifications.models.update_subscription import UpdateSubscription
from lusid_notifications.models.webhook_notification_type import WebhookNotificationType
from lusid_notifications.models.webhook_notification_type_response import WebhookNotificationTypeResponse

# import extensions into sdk package
from lusid_notifications.extensions import (
    SyncApiClientFactory,
    ApiClientFactory,
    ConfigurationLoader,
    SecretsFileConfigurationLoader,
    EnvironmentVariablesConfigurationLoader,
    ArgsConfigurationLoader,
    SyncApiClient
)


__all__ = [
    "ApplicationMetadataApi",
    "DeliveriesApi",
    "EventTypesApi",
    "ManualEventApi",
    "NotificationsApi",
    "SubscriptionsApi",
    "AccessControlledAction",
    "AccessControlledResource",
    "ActionId",
    "AmazonSqsNotificationType",
    "AmazonSqsNotificationTypeResponse",
    "AmazonSqsPrincipalAuthNotificationType",
    "AmazonSqsPrincipalAuthNotificationTypeResponse",
    "Attempt",
    "AttemptStatus",
    "CreateNotificationRequest",
    "CreateSubscription",
    "Delivery",
    "EmailNotificationType",
    "EmailNotificationTypeResponse",
    "EventFieldDefinition",
    "EventTypeSchema",
    "IdSelectorDefinition",
    "IdentifierPartSchema",
    "Link",
    "LusidProblemDetails",
    "LusidValidationProblemDetails",
    "ManualEvent",
    "ManualEventBody",
    "ManualEventHeader",
    "ManualEventRequest",
    "MatchingPattern",
    "Notification",
    "NotificationStatus",
    "NotificationType",
    "NotificationTypeResponse",
    "ResourceId",
    "ResourceListOfAccessControlledResource",
    "ResourceListOfDelivery",
    "ResourceListOfEventTypeSchema",
    "ResourceListOfNotification",
    "ResourceListOfSubscription",
    "SmsNotificationType",
    "SmsNotificationTypeResponse",
    "Subscription",
    "UpdateNotificationRequest",
    "UpdateSubscription",
    "WebhookNotificationType",
    "WebhookNotificationTypeResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiException",
    "SyncApiClientFactory", 
    "ApiClientFactory",
    "ConfigurationLoader",
    "SecretsFileConfigurationLoader",
    "EnvironmentVariablesConfigurationLoader",
    "ArgsConfigurationLoader",
    "SyncApiClient"
]


# coding: utf-8

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic.v1 import BaseModel, Field, StrictStr

class WebhookNotificationTypeResponse(BaseModel):
    """
    Holds readonly information about a Webhook notification  # noqa: E501
    """
    type: Optional[StrictStr] = Field(None, description="The type of delivery mechanism for this notification")
    http_method: Optional[StrictStr] = Field(None, alias="httpMethod", description="The HTTP method such as GET, POST, etc. to use on the request")
    url: Optional[StrictStr] = Field(None, description="The URL to send the request to")
    authentication_type: Optional[StrictStr] = Field(None, alias="authenticationType", description="The type of authentication to use on the request")
    authentication_configuration_item_paths: Optional[Dict[str, StrictStr]] = Field(None, alias="authenticationConfigurationItemPaths", description="The paths of the Configuration Store configuration items that contain the authentication configuration. Each  authentication type requires different keys:  - Lusid - None required  - BasicAuth - Requires 'Username' and 'Password'  - BearerToken - Requires 'BearerToken' and optionally 'BearerScheme'                e.g. the following would be valid assuming that the config is present in the configuration store at the  specified paths:                    \"authenticationType\": \"BasicAuth\",      \"authenticationConfigurationItemPaths\": {          \"Username\": \"config://personal/myUserId/WebhookConfigurations/ExampleService/AdminUser\",          \"Password\": \"config://personal/myUserId/WebhookConfigurations/ExampleService/AdminPassword\"      }")
    content_type: Optional[StrictStr] = Field(None, alias="contentType", description="The type of the content e.g. Json")
    content: Optional[Any] = Field(None, description="The content of the request")
    __properties = ["type", "httpMethod", "url", "authenticationType", "authenticationConfigurationItemPaths", "contentType", "content"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebhookNotificationTypeResponse:
        """Create an instance of WebhookNotificationTypeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if type (nullable) is None
        # and __fields_set__ contains the field
        if self.type is None and "type" in self.__fields_set__:
            _dict['type'] = None

        # set to None if http_method (nullable) is None
        # and __fields_set__ contains the field
        if self.http_method is None and "http_method" in self.__fields_set__:
            _dict['httpMethod'] = None

        # set to None if url (nullable) is None
        # and __fields_set__ contains the field
        if self.url is None and "url" in self.__fields_set__:
            _dict['url'] = None

        # set to None if authentication_type (nullable) is None
        # and __fields_set__ contains the field
        if self.authentication_type is None and "authentication_type" in self.__fields_set__:
            _dict['authenticationType'] = None

        # set to None if authentication_configuration_item_paths (nullable) is None
        # and __fields_set__ contains the field
        if self.authentication_configuration_item_paths is None and "authentication_configuration_item_paths" in self.__fields_set__:
            _dict['authenticationConfigurationItemPaths'] = None

        # set to None if content_type (nullable) is None
        # and __fields_set__ contains the field
        if self.content_type is None and "content_type" in self.__fields_set__:
            _dict['contentType'] = None

        # set to None if content (nullable) is None
        # and __fields_set__ contains the field
        if self.content is None and "content" in self.__fields_set__:
            _dict['content'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebhookNotificationTypeResponse:
        """Create an instance of WebhookNotificationTypeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WebhookNotificationTypeResponse.parse_obj(obj)

        _obj = WebhookNotificationTypeResponse.parse_obj({
            "type": obj.get("type"),
            "http_method": obj.get("httpMethod"),
            "url": obj.get("url"),
            "authentication_type": obj.get("authenticationType"),
            "authentication_configuration_item_paths": obj.get("authenticationConfigurationItemPaths"),
            "content_type": obj.get("contentType"),
            "content": obj.get("content")
        })
        return _obj
